## Summary
Brief description of changes.

## Changes
-
-

## Related Issues
Fixes #

## Testing
- [ ] Tests added/updated
- [ ] All tests passing (`uv run pytest`)
- [ ] Code formatted (`uv run black gridfia/ tests/`)

## Checklist
- [ ] Documentation updated (if applicable)
- [ ] CHANGELOG.md updated (if applicable)
- [ ] No breaking changes (or documented in description)
